@@ -489,6 +489,11 @@ class Mailing:
         """Mailing's unique identifier."""
         return self._id
 
+    @property
+    def mailing_link(self) -> str:
+        """This is the link to the mailing list inside of AMcards.com."""
+        return f'https://amcards.com/cards/history/?mailing={self._id}'
+
     @property
     def amount_charged(self) -> int:
         """Total amount charged to client's user in `cents`."""
@@ -515,7 +520,7 @@ class Mailing:
     #     return cls(
     #         id=json['id'],
     #         amount_charged=int(json['amount_charged']),
-    #         status=CardStatus(json['status']),
+    #         status=MailingStatus(json['status']),
     #         date_created=helpers.to_datetime(json['created']),
     #     )
 
